Class: Aws::Artifact::Types::ListComplianceInquiriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Artifact::Types::ListComplianceInquiriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-artifact/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Maximum number of resources to return in the paginated response.
-
#next_token ⇒ String
Pagination token to request the next page of resources.
Instance Attribute Details
#max_results ⇒ Integer
Maximum number of resources to return in the paginated response.
573 574 575 576 577 578 |
# File 'lib/aws-sdk-artifact/types.rb', line 573 class ListComplianceInquiriesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token to request the next page of resources.
573 574 575 576 577 578 |
# File 'lib/aws-sdk-artifact/types.rb', line 573 class ListComplianceInquiriesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |