Class: Aws::Artifact::Types::PutComplianceInquiryFeedbackRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Artifact::Types::PutComplianceInquiryFeedbackRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-artifact/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:comment]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#comment ⇒ String
An optional comment for the feedback.
-
#compliance_inquiry_id ⇒ String
The unique identifier for the compliance inquiry.
-
#query_identifier ⇒ Integer
The sequential identifier of the query to provide feedback on.
-
#rating ⇒ String
The rating for the feedback.
-
#reason_codes ⇒ Array<String>
The reason codes that describe why you rated the response.
-
#response_revision_id ⇒ Integer
The response revision ID.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request, but does not return an error.
A suitable default value is auto-generated. You should normally not need to pass this option.
830 831 832 833 834 835 836 837 838 839 840 |
# File 'lib/aws-sdk-artifact/types.rb', line 830 class PutComplianceInquiryFeedbackRequest < Struct.new( :compliance_inquiry_id, :query_identifier, :rating, :response_revision_id, :reason_codes, :comment, :client_token) SENSITIVE = [:comment] include Aws::Structure end |
#comment ⇒ String
An optional comment for the feedback.
830 831 832 833 834 835 836 837 838 839 840 |
# File 'lib/aws-sdk-artifact/types.rb', line 830 class PutComplianceInquiryFeedbackRequest < Struct.new( :compliance_inquiry_id, :query_identifier, :rating, :response_revision_id, :reason_codes, :comment, :client_token) SENSITIVE = [:comment] include Aws::Structure end |
#compliance_inquiry_id ⇒ String
The unique identifier for the compliance inquiry.
830 831 832 833 834 835 836 837 838 839 840 |
# File 'lib/aws-sdk-artifact/types.rb', line 830 class PutComplianceInquiryFeedbackRequest < Struct.new( :compliance_inquiry_id, :query_identifier, :rating, :response_revision_id, :reason_codes, :comment, :client_token) SENSITIVE = [:comment] include Aws::Structure end |
#query_identifier ⇒ Integer
The sequential identifier of the query to provide feedback on.
830 831 832 833 834 835 836 837 838 839 840 |
# File 'lib/aws-sdk-artifact/types.rb', line 830 class PutComplianceInquiryFeedbackRequest < Struct.new( :compliance_inquiry_id, :query_identifier, :rating, :response_revision_id, :reason_codes, :comment, :client_token) SENSITIVE = [:comment] include Aws::Structure end |
#rating ⇒ String
The rating for the feedback. Valid values are THUMBS_UP and THUMBS_DOWN.
830 831 832 833 834 835 836 837 838 839 840 |
# File 'lib/aws-sdk-artifact/types.rb', line 830 class PutComplianceInquiryFeedbackRequest < Struct.new( :compliance_inquiry_id, :query_identifier, :rating, :response_revision_id, :reason_codes, :comment, :client_token) SENSITIVE = [:comment] include Aws::Structure end |
#reason_codes ⇒ Array<String>
The reason codes that describe why you rated the response. Valid values are OTHER, PARTIAL_RESPONSE, and IRRELEVANT_RESPONSE.
830 831 832 833 834 835 836 837 838 839 840 |
# File 'lib/aws-sdk-artifact/types.rb', line 830 class PutComplianceInquiryFeedbackRequest < Struct.new( :compliance_inquiry_id, :query_identifier, :rating, :response_revision_id, :reason_codes, :comment, :client_token) SENSITIVE = [:comment] include Aws::Structure end |
#response_revision_id ⇒ Integer
The response revision ID. Use this value to prevent submitting feedback on a stale response.
830 831 832 833 834 835 836 837 838 839 840 |
# File 'lib/aws-sdk-artifact/types.rb', line 830 class PutComplianceInquiryFeedbackRequest < Struct.new( :compliance_inquiry_id, :query_identifier, :rating, :response_revision_id, :reason_codes, :comment, :client_token) SENSITIVE = [:comment] include Aws::Structure end |