Class: Aws::Artifact::Types::ReportDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::Artifact::Types::ReportDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-artifact/types.rb
Overview
Full detail for report resource metadata.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acceptance_type ⇒ String
Acceptance type for report.
-
#arn ⇒ String
ARN for the report resource.
-
#category ⇒ String
Category for the report resource.
-
#company_name ⇒ String
Associated company name for the report resource.
-
#created_at ⇒ Time
Timestamp indicating when the report resource was created.
-
#deleted_at ⇒ Time
Timestamp indicating when the report resource was deleted.
-
#description ⇒ String
Description for the report resource.
-
#id ⇒ String
Unique resource ID for the report resource.
-
#last_modified_at ⇒ Time
Timestamp indicating when the report resource was last modified.
-
#name ⇒ String
Name for the report resource.
-
#period_end ⇒ Time
Timestamp indicating the report resource effective end.
-
#period_start ⇒ Time
Timestamp indicating the report resource effective start.
-
#product_name ⇒ String
Associated product name for the report resource.
-
#sequence_number ⇒ Integer
Sequence number to enforce optimistic locking.
-
#series ⇒ String
Series for the report resource.
-
#state ⇒ String
Current state of the report resource.
-
#status_message ⇒ String
The message associated with the current upload state.
-
#term_arn ⇒ String
Unique resource ARN for term resource.
-
#upload_state ⇒ String
The current state of the document upload.
-
#version ⇒ Integer
Version for the report resource.
Instance Attribute Details
#acceptance_type ⇒ String
Acceptance type for report.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
ARN for the report resource.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
Category for the report resource.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#company_name ⇒ String
Associated company name for the report resource.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Timestamp indicating when the report resource was created.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#deleted_at ⇒ Time
Timestamp indicating when the report resource was deleted.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description for the report resource.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Unique resource ID for the report resource.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#last_modified_at ⇒ Time
Timestamp indicating when the report resource was last modified.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name for the report resource.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#period_end ⇒ Time
Timestamp indicating the report resource effective end.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#period_start ⇒ Time
Timestamp indicating the report resource effective start.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#product_name ⇒ String
Associated product name for the report resource.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#sequence_number ⇒ Integer
Sequence number to enforce optimistic locking.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#series ⇒ String
Series for the report resource.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Current state of the report resource
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The message associated with the current upload state.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#term_arn ⇒ String
Unique resource ARN for term resource.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#upload_state ⇒ String
The current state of the document upload.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
Version for the report resource.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-artifact/types.rb', line 486 class ReportDetail < Struct.new( :id, :name, :description, :period_start, :period_end, :created_at, :last_modified_at, :deleted_at, :state, :arn, :series, :category, :company_name, :product_name, :term_arn, :version, :acceptance_type, :sequence_number, :upload_state, :status_message) SENSITIVE = [] include Aws::Structure end |