Class: Aws::Artifact::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Artifact::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-artifact/client.rb,
sig/client.rbs
Overview
An API client for Artifact. To construct a client, you need to configure a :region and :credentials.
client = Aws::Artifact::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateComplianceInquiryResponseSuccess, _ExportComplianceInquiryResponseSuccess, _GetAccountSettingsResponseSuccess, _GetComplianceInquiryMetadataResponseSuccess, _GetReportMetadataResponseSuccess, _GetReportResponseSuccess, _GetTermForReportResponseSuccess, _ListComplianceInquiriesResponseSuccess, _ListComplianceInquiryQueriesResponseSuccess, _ListCustomerAgreementsResponseSuccess, _ListReportVersionsResponseSuccess, _ListReportsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutAccountSettingsResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_compliance_inquiry(params = {}) ⇒ Types::CreateComplianceInquiryResponse
Create a new compliance inquiry.
-
#export_compliance_inquiry(params = {}) ⇒ Types::ExportComplianceInquiryResponse
Export a compliance inquiry report.
-
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Get the account settings for Artifact.
-
#get_compliance_inquiry_metadata(params = {}) ⇒ Types::GetComplianceInquiryMetadataResponse
Get the metadata for a single compliance inquiry.
-
#get_report(params = {}) ⇒ Types::GetReportResponse
Get the content for a single report.
-
#get_report_metadata(params = {}) ⇒ Types::GetReportMetadataResponse
Get the metadata for a single report.
-
#get_term_for_report(params = {}) ⇒ Types::GetTermForReportResponse
Get the Term content associated with a single report.
-
#list_compliance_inquiries(params = {}) ⇒ Types::ListComplianceInquiriesResponse
List available compliance inquiries.
-
#list_compliance_inquiry_queries(params = {}) ⇒ Types::ListComplianceInquiryQueriesResponse
List queries within a compliance inquiry.
-
#list_customer_agreements(params = {}) ⇒ Types::ListCustomerAgreementsResponse
List active customer-agreements applicable to calling identity.
-
#list_report_versions(params = {}) ⇒ Types::ListReportVersionsResponse
List available report versions for a given report.
-
#list_reports(params = {}) ⇒ Types::ListReportsResponse
List available reports.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
-
#put_account_settings(params = {}) ⇒ Types::PutAccountSettingsResponse
Put the account settings for Artifact.
-
#tag_resource(params = {}) ⇒ Struct
Add tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Remove tags from a resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-artifact/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1471 1472 1473 |
# File 'lib/aws-sdk-artifact/client.rb', line 1471 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1474 1475 1476 |
# File 'lib/aws-sdk-artifact/client.rb', line 1474 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 |
# File 'lib/aws-sdk-artifact/client.rb', line 1444 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Artifact') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-artifact' context[:gem_version] = '1.39.0' Seahorse::Client::Request.new(handlers, context) end |
#create_compliance_inquiry(params = {}) ⇒ Types::CreateComplianceInquiryResponse
Create a new compliance inquiry.
87 |
# File 'sig/client.rbs', line 87
def create_compliance_inquiry: (
|
#export_compliance_inquiry(params = {}) ⇒ Types::ExportComplianceInquiryResponse
Export a compliance inquiry report.
108 |
# File 'sig/client.rbs', line 108
def export_compliance_inquiry: (
|
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Get the account settings for Artifact.
120 |
# File 'sig/client.rbs', line 120
def get_account_settings: (
|
#get_compliance_inquiry_metadata(params = {}) ⇒ Types::GetComplianceInquiryMetadataResponse
Get the metadata for a single compliance inquiry.
130 |
# File 'sig/client.rbs', line 130
def get_compliance_inquiry_metadata: (
|
#get_report(params = {}) ⇒ Types::GetReportResponse
Get the content for a single report.
140 |
# File 'sig/client.rbs', line 140
def get_report: (
|
#get_report_metadata(params = {}) ⇒ Types::GetReportMetadataResponse
Get the metadata for a single report.
152 |
# File 'sig/client.rbs', line 152
def get_report_metadata: (
|
#get_term_for_report(params = {}) ⇒ Types::GetTermForReportResponse
Get the Term content associated with a single report.
164 |
# File 'sig/client.rbs', line 164
def get_term_for_report: (
|
#list_compliance_inquiries(params = {}) ⇒ Types::ListComplianceInquiriesResponse
List available compliance inquiries.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
176 |
# File 'sig/client.rbs', line 176
def list_compliance_inquiries: (
|
#list_compliance_inquiry_queries(params = {}) ⇒ Types::ListComplianceInquiryQueriesResponse
List queries within a compliance inquiry.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
188 |
# File 'sig/client.rbs', line 188
def list_compliance_inquiry_queries: (
|
#list_customer_agreements(params = {}) ⇒ Types::ListCustomerAgreementsResponse
List active customer-agreements applicable to calling identity.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
201 |
# File 'sig/client.rbs', line 201
def list_customer_agreements: (
|
#list_report_versions(params = {}) ⇒ Types::ListReportVersionsResponse
List available report versions for a given report.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
213 |
# File 'sig/client.rbs', line 213
def list_report_versions: (
|
#list_reports(params = {}) ⇒ Types::ListReportsResponse
List available reports.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
226 |
# File 'sig/client.rbs', line 226
def list_reports: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
237 |
# File 'sig/client.rbs', line 237
def list_tags_for_resource: (
|
#put_account_settings(params = {}) ⇒ Types::PutAccountSettingsResponse
Put the account settings for Artifact.
247 |
# File 'sig/client.rbs', line 247
def put_account_settings: (
|
#tag_resource(params = {}) ⇒ Struct
Add tags to a resource.
256 |
# File 'sig/client.rbs', line 256
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Remove tags from a resource.
266 |
# File 'sig/client.rbs', line 266
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1464 1465 1466 |
# File 'lib/aws-sdk-artifact/client.rb', line 1464 def waiter_names [] end |