Class: Aws::Artifact::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Artifact::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-artifact/client.rb
Overview
An API client for Artifact. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Artifact::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Get the account settings for Artifact.
-
#get_report(params = {}) ⇒ Types::GetReportResponse
Get the content for a single report.
-
#get_report_metadata(params = {}) ⇒ Types::GetReportMetadataResponse
Get the metadata for a single report.
-
#get_term_for_report(params = {}) ⇒ Types::GetTermForReportResponse
Get the Term content associated with a single report.
-
#list_customer_agreements(params = {}) ⇒ Types::ListCustomerAgreementsResponse
List active customer-agreements applicable to calling identity.
-
#list_report_versions(params = {}) ⇒ Types::ListReportVersionsResponse
List available report versions for a given report.
-
#list_reports(params = {}) ⇒ Types::ListReportsResponse
List available reports.
-
#put_account_settings(params = {}) ⇒ Types::PutAccountSettingsResponse
Put the account settings for Artifact.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-artifact/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1021 1022 1023 |
# File 'lib/aws-sdk-artifact/client.rb', line 1021 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1024 1025 1026 |
# File 'lib/aws-sdk-artifact/client.rb', line 1024 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 |
# File 'lib/aws-sdk-artifact/client.rb', line 994 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Artifact') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-artifact' context[:gem_version] = '1.37.0' Seahorse::Client::Request.new(handlers, context) end |
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Get the account settings for Artifact.
506 507 508 509 |
# File 'lib/aws-sdk-artifact/client.rb', line 506 def get_account_settings(params = {}, = {}) req = build_request(:get_account_settings, params) req.send_request() end |
#get_report(params = {}) ⇒ Types::GetReportResponse
Get the content for a single report.
560 561 562 563 |
# File 'lib/aws-sdk-artifact/client.rb', line 560 def get_report(params = {}, = {}) req = build_request(:get_report, params) req.send_request() end |
#get_report_metadata(params = {}) ⇒ Types::GetReportMetadataResponse
Get the metadata for a single report.
641 642 643 644 |
# File 'lib/aws-sdk-artifact/client.rb', line 641 def (params = {}, = {}) req = build_request(:get_report_metadata, params) req.send_request() end |
#get_term_for_report(params = {}) ⇒ Types::GetTermForReportResponse
Get the Term content associated with a single report.
691 692 693 694 |
# File 'lib/aws-sdk-artifact/client.rb', line 691 def get_term_for_report(params = {}, = {}) req = build_request(:get_term_for_report, params) req.send_request() end |
#list_customer_agreements(params = {}) ⇒ Types::ListCustomerAgreementsResponse
List active customer-agreements applicable to calling identity.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
775 776 777 778 |
# File 'lib/aws-sdk-artifact/client.rb', line 775 def list_customer_agreements(params = {}, = {}) req = build_request(:list_customer_agreements, params) req.send_request() end |
#list_report_versions(params = {}) ⇒ Types::ListReportVersionsResponse
List available report versions for a given report.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
861 862 863 864 |
# File 'lib/aws-sdk-artifact/client.rb', line 861 def list_report_versions(params = {}, = {}) req = build_request(:list_report_versions, params) req.send_request() end |
#list_reports(params = {}) ⇒ Types::ListReportsResponse
List available reports.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
941 942 943 944 |
# File 'lib/aws-sdk-artifact/client.rb', line 941 def list_reports(params = {}, = {}) req = build_request(:list_reports, params) req.send_request() end |
#put_account_settings(params = {}) ⇒ Types::PutAccountSettingsResponse
Put the account settings for Artifact.
985 986 987 988 |
# File 'lib/aws-sdk-artifact/client.rb', line 985 def put_account_settings(params = {}, = {}) req = build_request(:put_account_settings, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1014 1015 1016 |
# File 'lib/aws-sdk-artifact/client.rb', line 1014 def waiter_names [] end |